#
# spec file for package python-zope.location
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2013 LISA GmbH, Bingen, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor test%{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif
%{?sle15_python_module_pythons}
Name:           python-zope.location%{psuffix}
Version:        5.0
Release:        2.3
Summary:        Zope Location
License:        ZPL-2.1
Group:          Development/Languages/Python
URL:            https://www.python.org/pypi/zope.location
Source:         https://files.pythonhosted.org/packages/source/z/zope.location/zope.location-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module wheel}
BuildRequires:  %{python_module zope.schema >= 4.2.2}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-zope.interface >= 4.0.2
Requires:       python-zope.proxy >= 4.0.1
Requires:       python-zope.schema >= 4.2.2
BuildArch:      noarch
%if %{with test}
BuildRequires:  %{python_module zope.component >= 4.0.1}
BuildRequires:  %{python_module zope.configuration}
BuildRequires:  %{python_module zope.copy >= 4.0}
BuildRequires:  %{python_module zope.proxy}
BuildRequires:  %{python_module zope.testrunner}
%endif
%python_subpackages

%description
In Zope3, location are special objects that has a structural location.

%prep
%setup -q -n zope.location-%{version}
rm -rf src/zope.location.egg-info

%build
%pyproject_wheel

%install
%if !%{with test}
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%if %{with test}
%check
# https://github.com/zopefoundation/zope.location/issues/12
rm src/zope/location/tests/test_configure.py
%python_expand PYTHONPATH=src %{_bindir}/zope-testrunner-%{$python_bin_suffix} -vvv --test-path src
%endif

%if !%{with test}
%files %{python_files}
%license LICENSE.txt
%doc COPYRIGHT.txt CHANGES.rst README.rst
%{python_sitelib}/*
%endif

%changelog
* Fri Jan  3 2025 Markéta Machová <mmachova@suse.com>
- Skip failing test and open an issue upstream
* Mon Dec 18 2023 Dirk Müller <dmueller@suse.com>
- update to 5.0:
  * Drop support for Python 2.7, 3.5, 3.6.
* Fri Jun  9 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Wed Dec  7 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 4.3
  * Add support for Python 3.8, 3.9, 3.10, 3.11.
  * Drop support for Python 3.4.
* Fri Apr  5 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to version 4.2
  * Add support for Python 3.5, 3.6 and 3.7.
  * Drop support for Python 2.6, 3.2 and 3.3.
  * Add a page to the docs on hacking zope.location.
  * Note additional documentation dependencies.
  * Remove internal _compat implementation module.
- drop *-doc subpackage, use multibuild instead.
* Thu Jul 13 2017 aloisio@gmx.com
- Update to version 4.0.3
  * Added Python 3.4 support.
  * Updated boostrap.py to version 2.2.
- Split docs and tests into separate -doc package since running
  tests and sometimes building docs had become very messy.
  Also see (gh#/zopefoundation/zope.proxy#18)
- Converted to single-spec
* Mon Jul 29 2013 hpj@urpla.net
- version 4.0.2: initial build
